"""
Optics
"""

NAME = "Optics"

DESCRIPTION = "Optics."

BACKGROUND = "#b9d47a"

ICON = "icons/optical_elements.png"

PRIORITY = 1005
